@@ -136,9 +136,26 @@ def is_main_process():
 
 
 def only_print_on_main_process(*args, sep=' ', end='\n', file=None, flush=True):
+    # 获取被调用函数在被调用时所处代码行数
     if is_main_process():
-        nb_print(*args, sep=sep, end=end, file=file, flush=flush)
-
+        args = (str(arg) for arg in args)  # REMIND 防止是数字不能被join
+        if file == sys.stderr:
+            stderr_write(sep.join(args))  # 如 threading 模块第926行，打印线程错误，希望保持原始的红色错误方式，不希望转成蓝色。
+        elif file in [sys.stdout, None]:
+            # 获取被调用函数在被调用时所处代码行数
+            line = sys._getframe().f_back.f_lineno
+            # 获取被调用函数所在模块文件名
+            file_name = sys._getframe(1).f_code.co_filename
+            # sys.stdout.write(f'"{__file__}:{sys._getframe().f_lineno}"    {x}\n')
+            if True:
+                stdout_write(
+                    f'\033[0;34m{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   \033[0;30;44m{sep.join(args)}\033[0m{end} \033[0m')  # 36  93 96 94
+            else:
+                stdout_write(
+                    f'\033[0;34m{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   {sep.join(args)} {end} \033[0m')  # 36  93 96 94
+            # sys.stdout.write(f'\033[0;30;44m"{file_name}:{line}"  {time.strftime("%H:%M:%S")}  {"".join(args)}\033[0m\n')
+        else:  # 例如traceback模块的print_exception函数 file的入参是   <_io.StringIO object at 0x00000264F2F065E8>，必须把内容重定向到这个对象里面，否则exception日志记录不了错误堆栈。
+            print_raw(*args, sep=sep, end=end, file=file)
 
 if __name__ == '__main__':
     print('before patch')
